User-controlled parameters have resulted in triggering a server-side DNS request. The ability to control the server side is
not a vulnerability. However, it is a serious indication of potentially high-risk vulnerability.

An attacker may leverage this functionality to send requests to remote systems for denial of service attacks or exploit potential vulnerabilities remotely. It is also potentially possible to access internal systems protected with
external network filtering.
